@@ -28,6 +28,7 @@ class DocumentModel : public QAbstractListModel
     Q_PROPERTY(QUrl activePageSource READ activePageSource NOTIFY activePageChanged)
     Q_PROPERTY(int activePageRotation READ activePageRotation NOTIFY activePageChanged)
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
+    Q_PROPERTY(bool isReady READ isReady NOTIFY isReadyChanged)
     
 public:
     enum DocumentModelRoles { ImageUrlRole = Qt::UserRole + 1,
@@ -43,6 +44,12 @@ public:
 
     Q_ENUM(RotateOption)
 
+    enum FlipPagesOption { FlipEven,
+        FlipOdd,
+        FlipAll};
+
+    Q_ENUM(FlipPagesOption)
+
     enum ReorderOption { ReorderDuplex,
         ReorderDuplexReversed,
         Reverse};
@@ -58,6 +65,7 @@ public:
     int activePageRotation() const;
     QUrl activePageSource() const;
     bool changed() const;
+    bool isReady() const;
 
     void setActivePageIndex(int);
 
@@ -71,6 +79,8 @@ public:
 
     Q_INVOKABLE void rotateImage(int row, RotateOption rotate = RotateOption::Rotate90positive);
 
+    Q_INVOKABLE void flipPages(FlipPagesOption flip);
+
     Q_INVOKABLE void reorderPages(ReorderOption reorder);
 
     Q_INVOKABLE void save(const QUrl &fileUrl, const QList<int> &pageNumbers = {});
@@ -90,6 +100,7 @@ Q_SIGNALS:
     void changedChanged();
     void activePageChanged();
     void countChanged();
+    void isReadyChanged(const bool isReady);
     void newPageAdded();
     void saveDocument(const QUrl &fileUrl, const SkanpageUtils::DocumentPages &document, const SkanpageUtils::FileType type = SkanpageUtils::EntireDocument, const QString &title = QString());
     void saveNewPageTemporary(const int pageID, const QImage &image);
